On Win32/mingw32 the name 'interface' is #defined to the COM_interface
struct. Needless to say, libvirt thus fails to build in spectacular ways.
This patch does s/interface/iface/ on all variables. It also fixes
bugs in the qemud/Makefile.am and tests/testutils.h files
include/libvirt/libvirt.h | 18 +++---
include/libvirt/libvirt.h.in | 18 +++---
qemud/Makefile.am | 6 +-
qemud/remote.c | 82 ++++++++++++++---------------
qemud/remote_protocol.c | 14 ++---
qemud/remote_protocol.h | 14 ++---
qemud/remote_protocol.x | 14 ++---
src/datatypes.c | 36 ++++++------
src/datatypes.h | 2
src/driver.h | 8 +-
src/libvirt.c | 120 +++++++++++++++++++++----------------------
src/remote_internal.c | 56 ++++++++++----------
tests/testutils.c | 10 +++
13 files changed, 206 insertions(+), 192 deletions(-)
Daniel
Index: include/libvirt/libvirt.h
===================================================================
RCS file: /data/cvs/libvirt/include/libvirt/libvirt.h,v
retrieving revision 1.105
diff -u -p -r1.105 libvirt.h
--- include/libvirt/libvirt.h 21 May 2009 13:46:36 -0000 1.105
+++ include/libvirt/libvirt.h 28 May 2009 16:32:53 -0000
@@ -883,7 +883,7 @@ typedef struct _virInterface virInterfac
*/
typedef virInterface *virInterfacePtr;
-virConnectPtr virInterfaceGetConnect (virInterfacePtr interface);
+virConnectPtr virInterfaceGetConnect (virInterfacePtr iface);
int virConnectNumOfInterfaces (virConnectPtr conn);
int virConnectListInterfaces (virConnectPtr conn,
@@ -895,25 +895,25 @@ virInterfacePtr virInterfaceLook
virInterfacePtr virInterfaceLookupByMACString (virConnectPtr conn,
const char *mac);
-const char* virInterfaceGetName (virInterfacePtr interface);
-const char* virInterfaceGetMACString (virInterfacePtr interface);
+const char* virInterfaceGetName (virInterfacePtr iface);
+const char* virInterfaceGetMACString (virInterfacePtr iface);
-char * virInterfaceGetXMLDesc (virInterfacePtr interface,
+char * virInterfaceGetXMLDesc (virInterfacePtr iface,
unsigned int flags);
virInterfacePtr virInterfaceDefineXML (virConnectPtr conn,
const char *xmlDesc,
unsigned int flags);
-int virInterfaceUndefine (virInterfacePtr interface);
+int virInterfaceUndefine (virInterfacePtr iface);
-int virInterfaceCreate (virInterfacePtr interface,
+int virInterfaceCreate (virInterfacePtr iface,
unsigned int flags);
-int virInterfaceDestroy (virInterfacePtr interface,
+int virInterfaceDestroy (virInterfacePtr iface,
unsigned int flags);
-int virInterfaceRef (virInterfacePtr interface);
-int virInterfaceFree (virInterfacePtr interface);
+int virInterfaceRef (virInterfacePtr iface);
+int virInterfaceFree (virInterfacePtr iface);
/**
* virStoragePool:
Index: include/libvirt/libvirt.h.in
===================================================================
RCS file: /data/cvs/libvirt/include/libvirt/libvirt.h.in,v
retrieving revision 1.70
diff -u -p -r1.70 libvirt.h.in
--- include/libvirt/libvirt.h.in 21 May 2009 13:46:36 -0000 1.70
+++ include/libvirt/libvirt.h.in 28 May 2009 16:32:53 -0000
@@ -883,7 +883,7 @@ typedef struct _virInterface virInterfac
*/
typedef virInterface *virInterfacePtr;
-virConnectPtr virInterfaceGetConnect (virInterfacePtr interface);
+virConnectPtr virInterfaceGetConnect (virInterfacePtr iface);
int virConnectNumOfInterfaces (virConnectPtr conn);
int virConnectListInterfaces (virConnectPtr conn,
@@ -895,25 +895,25 @@ virInterfacePtr virInterfaceLook
virInterfacePtr virInterfaceLookupByMACString (virConnectPtr conn,
const char *mac);
-const char* virInterfaceGetName (virInterfacePtr interface);
-const char* virInterfaceGetMACString (virInterfacePtr interface);
+const char* virInterfaceGetName (virInterfacePtr iface);
+const char* virInterfaceGetMACString (virInterfacePtr iface);
-char * virInterfaceGetXMLDesc (virInterfacePtr interface,
+char * virInterfaceGetXMLDesc (virInterfacePtr iface,
unsigned int flags);
virInterfacePtr virInterfaceDefineXML (virConnectPtr conn,
const char *xmlDesc,
unsigned int flags);
-int virInterfaceUndefine (virInterfacePtr interface);
+int virInterfaceUndefine (virInterfacePtr iface);
-int virInterfaceCreate (virInterfacePtr interface,
+int virInterfaceCreate (virInterfacePtr iface,
unsigned int flags);
-int virInterfaceDestroy (virInterfacePtr interface,
+int virInterfaceDestroy (virInterfacePtr iface,
unsigned int flags);
-int virInterfaceRef (virInterfacePtr interface);
-int virInterfaceFree (virInterfacePtr interface);
+int virInterfaceRef (virInterfacePtr iface);
+int virInterfaceFree (virInterfacePtr iface);
/**
* virStoragePool:
Index: qemud/Makefile.am
===================================================================
RCS file: /data/cvs/libvirt/qemud/Makefile.am,v
retrieving revision 1.78
diff -u -p -r1.78 Makefile.am
--- qemud/Makefile.am 25 May 2009 11:56:00 -0000 1.78
+++ qemud/Makefile.am 28 May 2009 16:32:53 -0000
@@ -31,7 +31,7 @@ EXTRA_DIST = \
$(AVAHI_SOURCES) \
$(DAEMON_SOURCES)
-BUILT_SOURCES = libvirtd.init libvirtd.logrotate
+BUILT_SOURCES =
if HAVE_RPCGEN
#
@@ -218,6 +218,8 @@ remote_dispatch_args.h: $(srcdir)/remote
remote_dispatch_ret.h: $(srcdir)/remote_generate_stubs.pl remote_protocol.x
perl -w $(srcdir)/remote_generate_stubs.pl -r $(srcdir)/remote_protocol.x > $@
+BUILT_SOURCES += libvirtd.logrotate
+
libvirtd.logrotate: libvirtd.logrotate.in
sed \
-e s!\@localstatedir\@!@localstatedir@!g \
@@ -242,6 +244,8 @@ uninstall-init:
rm -f $(DESTDIR)$(sysconfdir)/rc.d/init.d/libvirtd \
$(DESTDIR)$(sysconfdir)/sysconfig/libvirtd
+BUILT_SOURCES += libvirtd.init
+
libvirtd.init: libvirtd.init.in
sed \
-e s!\@localstatedir\@!@localstatedir@!g \
Index: qemud/remote.c
===================================================================
RCS file: /data/cvs/libvirt/qemud/remote.c,v
retrieving revision 1.71
diff -u -p -r1.71 remote.c
--- qemud/remote.c 21 May 2009 13:50:56 -0000 1.71
+++ qemud/remote.c 28 May 2009 16:32:54 -0000
@@ -2664,16 +2664,16 @@ remoteDispatchInterfaceLookupByName (str
remote_interface_lookup_by_name_args *args,
remote_interface_lookup_by_name_ret *ret)
{
- virInterfacePtr interface;
+ virInterfacePtr iface;
- interface = virInterfaceLookupByName (conn, args->name);
- if (interface == NULL) {
+ iface = virInterfaceLookupByName (conn, args->name);
+ if (iface == NULL) {
remoteDispatchConnError(rerr, conn);
return -1;
}
- make_nonnull_interface (&ret->interface, interface);
- virInterfaceFree(interface);
+ make_nonnull_interface (&ret->iface, iface);
+ virInterfaceFree(iface);
return 0;
}
@@ -2685,16 +2685,16 @@ remoteDispatchInterfaceLookupByMacString
remote_interface_lookup_by_mac_string_args
*args,
remote_interface_lookup_by_mac_string_ret
*ret)
{
- virInterfacePtr interface;
+ virInterfacePtr iface;
- interface = virInterfaceLookupByMACString (conn, args->mac);
- if (interface == NULL) {
+ iface = virInterfaceLookupByMACString (conn, args->mac);
+ if (iface == NULL) {
remoteDispatchConnError(rerr, conn);
return -1;
}
- make_nonnull_interface (&ret->interface, interface);
- virInterfaceFree(interface);
+ make_nonnull_interface (&ret->iface, iface);
+ virInterfaceFree(iface);
return 0;
}
@@ -2706,22 +2706,22 @@ remoteDispatchInterfaceGetXmlDesc (struc
remote_interface_get_xml_desc_args *args,
remote_interface_get_xml_desc_ret *ret)
{
- virInterfacePtr interface;
+ virInterfacePtr iface;
- interface = get_nonnull_interface (conn, args->interface);
- if (interface == NULL) {
+ iface = get_nonnull_interface (conn, args->iface);
+ if (iface == NULL) {
remoteDispatchConnError(rerr, conn);
return -1;
}
/* remoteDispatchClientRequest will free this. */
- ret->xml = virInterfaceGetXMLDesc (interface, args->flags);
+ ret->xml = virInterfaceGetXMLDesc (iface, args->flags);
if (!ret->xml) {
- virInterfaceFree(interface);
+ virInterfaceFree(iface);
remoteDispatchConnError(rerr, conn);
return -1;
}
- virInterfaceFree(interface);
+ virInterfaceFree(iface);
return 0;
}
@@ -2733,16 +2733,16 @@ remoteDispatchInterfaceDefineXml (struct
remote_interface_define_xml_args *args,
remote_interface_define_xml_ret *ret)
{
- virInterfacePtr interface;
+ virInterfacePtr iface;
- interface = virInterfaceDefineXML (conn, args->xml, args->flags);
- if (interface == NULL) {
+ iface = virInterfaceDefineXML (conn, args->xml, args->flags);
+ if (iface == NULL) {
remoteDispatchConnError(rerr, conn);
return -1;
}
- make_nonnull_interface (&ret->interface, interface);
- virInterfaceFree(interface);
+ make_nonnull_interface (&ret->iface, iface);
+ virInterfaceFree(iface);
return 0;
}
@@ -2754,20 +2754,20 @@ remoteDispatchInterfaceUndefine (struct
remote_interface_undefine_args *args,
void *ret ATTRIBUTE_UNUSED)
{
- virInterfacePtr interface;
+ virInterfacePtr iface;
- interface = get_nonnull_interface (conn, args->interface);
- if (interface == NULL) {
+ iface = get_nonnull_interface (conn, args->iface);
+ if (iface == NULL) {
remoteDispatchConnError(rerr, conn);
return -1;
}
- if (virInterfaceUndefine (interface) == -1) {
- virInterfaceFree(interface);
+ if (virInterfaceUndefine (iface) == -1) {
+ virInterfaceFree(iface);
remoteDispatchConnError(rerr, conn);
return -1;
}
- virInterfaceFree(interface);
+ virInterfaceFree(iface);
return 0;
}
@@ -2779,20 +2779,20 @@ remoteDispatchInterfaceCreate (struct qe
remote_interface_create_args *args,
void *ret ATTRIBUTE_UNUSED)
{
- virInterfacePtr interface;
+ virInterfacePtr iface;
- interface = get_nonnull_interface (conn, args->interface);
- if (interface == NULL) {
+ iface = get_nonnull_interface (conn, args->iface);
+ if (iface == NULL) {
remoteDispatchConnError(rerr, conn);
return -1;
}
- if (virInterfaceCreate (interface, args->flags) == -1) {
- virInterfaceFree(interface);
+ if (virInterfaceCreate (iface, args->flags) == -1) {
+ virInterfaceFree(iface);
remoteDispatchConnError(rerr, conn);
return -1;
}
- virInterfaceFree(interface);
+ virInterfaceFree(iface);
return 0;
}
@@ -2804,20 +2804,20 @@ remoteDispatchInterfaceDestroy (struct q
remote_interface_destroy_args *args,
void *ret ATTRIBUTE_UNUSED)
{
- virInterfacePtr interface;
+ virInterfacePtr iface;
- interface = get_nonnull_interface (conn, args->interface);
- if (interface == NULL) {
+ iface = get_nonnull_interface (conn, args->iface);
+ if (iface == NULL) {
remoteDispatchConnError(rerr, conn);
return -1;
}
- if (virInterfaceDestroy (interface, args->flags) == -1) {
- virInterfaceFree(interface);
+ if (virInterfaceDestroy (iface, args->flags) == -1) {
+ virInterfaceFree(iface);
remoteDispatchConnError(rerr, conn);
return -1;
}
- virInterfaceFree(interface);
+ virInterfaceFree(iface);
return 0;
}
@@ -4823,9 +4823,9 @@ get_nonnull_network (virConnectPtr conn,
}
static virInterfacePtr
-get_nonnull_interface (virConnectPtr conn, remote_nonnull_interface interface)
+get_nonnull_interface (virConnectPtr conn, remote_nonnull_interface iface)
{
- return virGetInterface (conn, interface.name, interface.mac);
+ return virGetInterface (conn, iface.name, iface.mac);
}
static virStoragePoolPtr
Index: qemud/remote_protocol.c
===================================================================
RCS file: /data/cvs/libvirt/qemud/remote_protocol.c,v
retrieving revision 1.34
diff -u -p -r1.34 remote_protocol.c
--- qemud/remote_protocol.c 21 May 2009 13:50:56 -0000 1.34
+++ qemud/remote_protocol.c 28 May 2009 16:32:54 -0000
@@ -1530,7 +1530,7 @@ bool_t
xdr_remote_interface_lookup_by_name_ret (XDR *xdrs, remote_interface_lookup_by_name_ret
*objp)
{
- if (!xdr_remote_nonnull_interface (xdrs, &objp->interface))
+ if (!xdr_remote_nonnull_interface (xdrs, &objp->iface))
return FALSE;
return TRUE;
}
@@ -1548,7 +1548,7 @@ bool_t
xdr_remote_interface_lookup_by_mac_string_ret (XDR *xdrs,
remote_interface_lookup_by_mac_string_ret *objp)
{
- if (!xdr_remote_nonnull_interface (xdrs, &objp->interface))
+ if (!xdr_remote_nonnull_interface (xdrs, &objp->iface))
return FALSE;
return TRUE;
}
@@ -1557,7 +1557,7 @@ bool_t
xdr_remote_interface_get_xml_desc_args (XDR *xdrs, remote_interface_get_xml_desc_args
*objp)
{
- if (!xdr_remote_nonnull_interface (xdrs, &objp->interface))
+ if (!xdr_remote_nonnull_interface (xdrs, &objp->iface))
return FALSE;
if (!xdr_u_int (xdrs, &objp->flags))
return FALSE;
@@ -1588,7 +1588,7 @@ bool_t
xdr_remote_interface_define_xml_ret (XDR *xdrs, remote_interface_define_xml_ret *objp)
{
- if (!xdr_remote_nonnull_interface (xdrs, &objp->interface))
+ if (!xdr_remote_nonnull_interface (xdrs, &objp->iface))
return FALSE;
return TRUE;
}
@@ -1597,7 +1597,7 @@ bool_t
xdr_remote_interface_undefine_args (XDR *xdrs, remote_interface_undefine_args *objp)
{
- if (!xdr_remote_nonnull_interface (xdrs, &objp->interface))
+ if (!xdr_remote_nonnull_interface (xdrs, &objp->iface))
return FALSE;
return TRUE;
}
@@ -1606,7 +1606,7 @@ bool_t
xdr_remote_interface_create_args (XDR *xdrs, remote_interface_create_args *objp)
{
- if (!xdr_remote_nonnull_interface (xdrs, &objp->interface))
+ if (!xdr_remote_nonnull_interface (xdrs, &objp->iface))
return FALSE;
if (!xdr_u_int (xdrs, &objp->flags))
return FALSE;
@@ -1617,7 +1617,7 @@ bool_t
xdr_remote_interface_destroy_args (XDR *xdrs, remote_interface_destroy_args *objp)
{
- if (!xdr_remote_nonnull_interface (xdrs, &objp->interface))
+ if (!xdr_remote_nonnull_interface (xdrs, &objp->iface))
return FALSE;
if (!xdr_u_int (xdrs, &objp->flags))
return FALSE;
Index: qemud/remote_protocol.h
===================================================================
RCS file: /data/cvs/libvirt/qemud/remote_protocol.h,v
retrieving revision 1.33
diff -u -p -r1.33 remote_protocol.h
--- qemud/remote_protocol.h 21 May 2009 13:50:56 -0000 1.33
+++ qemud/remote_protocol.h 28 May 2009 16:32:54 -0000
@@ -853,7 +853,7 @@ struct remote_interface_lookup_by_name_a
typedef struct remote_interface_lookup_by_name_args
remote_interface_lookup_by_name_args;
struct remote_interface_lookup_by_name_ret {
- remote_nonnull_interface interface;
+ remote_nonnull_interface iface;
};
typedef struct remote_interface_lookup_by_name_ret remote_interface_lookup_by_name_ret;
@@ -863,12 +863,12 @@ struct remote_interface_lookup_by_mac_st
typedef struct remote_interface_lookup_by_mac_string_args
remote_interface_lookup_by_mac_string_args;
struct remote_interface_lookup_by_mac_string_ret {
- remote_nonnull_interface interface;
+ remote_nonnull_interface iface;
};
typedef struct remote_interface_lookup_by_mac_string_ret
remote_interface_lookup_by_mac_string_ret;
struct remote_interface_get_xml_desc_args {
- remote_nonnull_interface interface;
+ remote_nonnull_interface iface;
u_int flags;
};
typedef struct remote_interface_get_xml_desc_args remote_interface_get_xml_desc_args;
@@ -885,23 +885,23 @@ struct remote_interface_define_xml_args
typedef struct remote_interface_define_xml_args remote_interface_define_xml_args;
struct remote_interface_define_xml_ret {
- remote_nonnull_interface interface;
+ remote_nonnull_interface iface;
};
typedef struct remote_interface_define_xml_ret remote_interface_define_xml_ret;
struct remote_interface_undefine_args {
- remote_nonnull_interface interface;
+ remote_nonnull_interface iface;
};
typedef struct remote_interface_undefine_args remote_interface_undefine_args;
struct remote_interface_create_args {
- remote_nonnull_interface interface;
+ remote_nonnull_interface iface;
u_int flags;
};
typedef struct remote_interface_create_args remote_interface_create_args;
struct remote_interface_destroy_args {
- remote_nonnull_interface interface;
+ remote_nonnull_interface iface;
u_int flags;
};
typedef struct remote_interface_destroy_args remote_interface_destroy_args;
Index: qemud/remote_protocol.x
===================================================================
RCS file: /data/cvs/libvirt/qemud/remote_protocol.x,v
retrieving revision 1.32
diff -u -p -r1.32 remote_protocol.x
--- qemud/remote_protocol.x 21 May 2009 13:50:56 -0000 1.32
+++ qemud/remote_protocol.x 28 May 2009 16:32:54 -0000
@@ -798,7 +798,7 @@ struct remote_interface_lookup_by_name_a
};
struct remote_interface_lookup_by_name_ret {
- remote_nonnull_interface interface;
+ remote_nonnull_interface iface;
};
struct remote_interface_lookup_by_mac_string_args {
@@ -806,11 +806,11 @@ struct remote_interface_lookup_by_mac_st
};
struct remote_interface_lookup_by_mac_string_ret {
- remote_nonnull_interface interface;
+ remote_nonnull_interface iface;
};
struct remote_interface_get_xml_desc_args {
- remote_nonnull_interface interface;
+ remote_nonnull_interface iface;
unsigned int flags;
};
@@ -824,20 +824,20 @@ struct remote_interface_define_xml_args
};
struct remote_interface_define_xml_ret {
- remote_nonnull_interface interface;
+ remote_nonnull_interface iface;
};
struct remote_interface_undefine_args {
- remote_nonnull_interface interface;
+ remote_nonnull_interface iface;
};
struct remote_interface_create_args {
- remote_nonnull_interface interface;
+ remote_nonnull_interface iface;
unsigned int flags;
};
struct remote_interface_destroy_args {
- remote_nonnull_interface interface;
+ remote_nonnull_interface iface;
unsigned int flags;
};
Index: src/datatypes.c
===================================================================
RCS file: /data/cvs/libvirt/src/datatypes.c,v
retrieving revision 1.12
diff -u -p -r1.12 datatypes.c
--- src/datatypes.c 20 May 2009 14:26:50 -0000 1.12
+++ src/datatypes.c 28 May 2009 16:32:54 -0000
@@ -75,9 +75,9 @@ virNetworkFreeName(virNetworkPtr network
* Returns 0 in case of success and -1 in case of failure.
*/
static int
-virInterfaceFreeName(virInterfacePtr interface, const char *name ATTRIBUTE_UNUSED)
+virInterfaceFreeName(virInterfacePtr iface, const char *name ATTRIBUTE_UNUSED)
{
- return (virUnrefInterface(interface));
+ return (virUnrefInterface(iface));
}
/**
@@ -589,19 +589,19 @@ virGetInterface(virConnectPtr conn, cons
* which may also be released if its ref count hits zero.
*/
static void
-virReleaseInterface(virInterfacePtr interface) {
- virConnectPtr conn = interface->conn;
- DEBUG("release interface %p %s", interface, interface->name);
+virReleaseInterface(virInterfacePtr iface) {
+ virConnectPtr conn = iface->conn;
+ DEBUG("release interface %p %s", iface, iface->name);
/* TODO search by MAC first as they are better differenciators */
- if (virHashRemoveEntry(conn->interfaces, interface->name, NULL) < 0)
+ if (virHashRemoveEntry(conn->interfaces, iface->name, NULL) < 0)
virLibConnError(conn, VIR_ERR_INTERNAL_ERROR,
_("interface missing from connection hash table"));
- interface->magic = -1;
- VIR_FREE(interface->name);
- VIR_FREE(interface->mac);
- VIR_FREE(interface);
+ iface->magic = -1;
+ VIR_FREE(iface->name);
+ VIR_FREE(iface->mac);
+ VIR_FREE(iface);
DEBUG("unref connection %p %d", conn, conn->refs);
conn->refs--;
@@ -625,24 +625,24 @@ virReleaseInterface(virInterfacePtr inte
* Returns the reference count or -1 in case of failure.
*/
int
-virUnrefInterface(virInterfacePtr interface) {
+virUnrefInterface(virInterfacePtr iface) {
int refs;
- if (!VIR_IS_CONNECTED_INTERFACE(interface)) {
+ if (!VIR_IS_CONNECTED_INTERFACE(iface)) {
virLibConnError(NULL, VIR_ERR_INVALID_ARG, __FUNCTION__);
return(-1);
}
- virMutexLock(&interface->conn->lock);
- DEBUG("unref interface %p %s %d", interface, interface->name,
interface->refs);
- interface->refs--;
- refs = interface->refs;
+ virMutexLock(&iface->conn->lock);
+ DEBUG("unref interface %p %s %d", iface, iface->name, iface->refs);
+ iface->refs--;
+ refs = iface->refs;
if (refs == 0) {
- virReleaseInterface(interface);
+ virReleaseInterface(iface);
/* Already unlocked mutex */
return (0);
}
- virMutexUnlock(&interface->conn->lock);
+ virMutexUnlock(&iface->conn->lock);
return (refs);
}
Index: src/datatypes.h
===================================================================
RCS file: /data/cvs/libvirt/src/datatypes.h,v
retrieving revision 1.8
diff -u -p -r1.8 datatypes.h
--- src/datatypes.h 20 May 2009 14:26:50 -0000 1.8
+++ src/datatypes.h 28 May 2009 16:32:54 -0000
@@ -254,7 +254,7 @@ int virUnrefNetwork(virNetworkPtr networ
virInterfacePtr virGetInterface(virConnectPtr conn,
const char *name,
const char *mac);
-int virUnrefInterface(virInterfacePtr interface);
+int virUnrefInterface(virInterfacePtr iface);
virStoragePoolPtr virGetStoragePool(virConnectPtr conn,
const char *name,
Index: src/driver.h
===================================================================
RCS file: /data/cvs/libvirt/src/driver.h,v
retrieving revision 1.75
diff -u -p -r1.75 driver.h
--- src/driver.h 25 May 2009 11:56:00 -0000 1.75
+++ src/driver.h 28 May 2009 16:32:54 -0000
@@ -516,7 +516,7 @@ typedef virInterfacePtr
const char *mac);
typedef char *
- (*virDrvInterfaceGetXMLDesc) (virInterfacePtr interface,
+ (*virDrvInterfaceGetXMLDesc) (virInterfacePtr iface,
unsigned int flags);
typedef virInterfacePtr
@@ -524,12 +524,12 @@ typedef virInterfacePtr
const char *xmlDesc,
unsigned int flags);
typedef int
- (*virDrvInterfaceUndefine) (virInterfacePtr interface);
+ (*virDrvInterfaceUndefine) (virInterfacePtr iface);
typedef int
- (*virDrvInterfaceCreate) (virInterfacePtr interface,
+ (*virDrvInterfaceCreate) (virInterfacePtr iface,
unsigned int flags);
typedef int
- (*virDrvInterfaceDestroy) (virInterfacePtr interface,
+ (*virDrvInterfaceDestroy) (virInterfacePtr iface,
unsigned int flags);
typedef struct _virInterfaceDriver virInterfaceDriver;
Index: src/remote_internal.c
===================================================================
RCS file: /data/cvs/libvirt/src/remote_internal.c,v
retrieving revision 1.153
diff -u -p -r1.153 remote_internal.c
--- src/remote_internal.c 21 May 2009 13:50:56 -0000 1.153
+++ src/remote_internal.c 28 May 2009 16:32:54 -0000
@@ -212,7 +212,7 @@ static void errorf (virConnectPtr conn,
static void server_error (virConnectPtr conn, remote_error *err);
static virDomainPtr get_nonnull_domain (virConnectPtr conn, remote_nonnull_domain
domain);
static virNetworkPtr get_nonnull_network (virConnectPtr conn, remote_nonnull_network
network);
-static virInterfacePtr get_nonnull_interface (virConnectPtr conn,
remote_nonnull_interface interface);
+static virInterfacePtr get_nonnull_interface (virConnectPtr conn,
remote_nonnull_interface iface);
static virStoragePoolPtr get_nonnull_storage_pool (virConnectPtr conn,
remote_nonnull_storage_pool pool);
static virStorageVolPtr get_nonnull_storage_vol (virConnectPtr conn,
remote_nonnull_storage_vol vol);
static virNodeDevicePtr get_nonnull_node_device (virConnectPtr conn,
remote_nonnull_node_device dev);
@@ -3876,7 +3876,7 @@ static virInterfacePtr
remoteInterfaceLookupByName (virConnectPtr conn,
const char *name)
{
- virInterfacePtr interface = NULL;
+ virInterfacePtr iface = NULL;
remote_interface_lookup_by_name_args args;
remote_interface_lookup_by_name_ret ret;
struct private_data *priv = conn->interfacePrivateData;
@@ -3891,19 +3891,19 @@ remoteInterfaceLookupByName (virConnectP
(xdrproc_t) xdr_remote_interface_lookup_by_name_ret, (char *) &ret) ==
-1)
goto done;
- interface = get_nonnull_interface (conn, ret.interface);
+ iface = get_nonnull_interface (conn, ret.iface);
xdr_free ((xdrproc_t) &xdr_remote_interface_lookup_by_name_ret, (char *)
&ret);
done:
remoteDriverUnlock(priv);
- return interface;
+ return iface;
}
static virInterfacePtr
remoteInterfaceLookupByMACString (virConnectPtr conn,
const char *mac)
{
- virInterfacePtr interface = NULL;
+ virInterfacePtr iface = NULL;
remote_interface_lookup_by_mac_string_args args;
remote_interface_lookup_by_mac_string_ret ret;
struct private_data *priv = conn->interfacePrivateData;
@@ -3918,30 +3918,30 @@ remoteInterfaceLookupByMACString (virCon
(xdrproc_t) xdr_remote_interface_lookup_by_mac_string_ret, (char *)
&ret) == -1)
goto done;
- interface = get_nonnull_interface (conn, ret.interface);
+ iface = get_nonnull_interface (conn, ret.iface);
xdr_free ((xdrproc_t) &xdr_remote_interface_lookup_by_mac_string_ret, (char *)
&ret);
done:
remoteDriverUnlock(priv);
- return interface;
+ return iface;
}
static char *
-remoteInterfaceGetXMLDesc (virInterfacePtr interface,
+remoteInterfaceGetXMLDesc (virInterfacePtr iface,
unsigned int flags)
{
char *rv = NULL;
remote_interface_get_xml_desc_args args;
remote_interface_get_xml_desc_ret ret;
- struct private_data *priv = interface->conn->interfacePrivateData;
+ struct private_data *priv = iface->conn->interfacePrivateData;
remoteDriverLock(priv);
- make_nonnull_interface (&args.interface, interface);
+ make_nonnull_interface (&args.iface, iface);
args.flags = flags;
memset (&ret, 0, sizeof ret);
- if (call (interface->conn, priv, 0, REMOTE_PROC_INTERFACE_GET_XML_DESC,
+ if (call (iface->conn, priv, 0, REMOTE_PROC_INTERFACE_GET_XML_DESC,
(xdrproc_t) xdr_remote_interface_get_xml_desc_args, (char *) &args,
(xdrproc_t) xdr_remote_interface_get_xml_desc_ret, (char *) &ret) ==
-1)
goto done;
@@ -3959,7 +3959,7 @@ remoteInterfaceDefineXML (virConnectPtr
const char *xmlDesc,
unsigned int flags)
{
- virInterfacePtr interface = NULL;
+ virInterfacePtr iface = NULL;
remote_interface_define_xml_args args;
remote_interface_define_xml_ret ret;
struct private_data *priv = conn->interfacePrivateData;
@@ -3975,26 +3975,26 @@ remoteInterfaceDefineXML (virConnectPtr
(xdrproc_t) xdr_remote_interface_define_xml_ret, (char *) &ret) == -1)
goto done;
- interface = get_nonnull_interface (conn, ret.interface);
+ iface = get_nonnull_interface (conn, ret.iface);
xdr_free ((xdrproc_t) &xdr_remote_interface_define_xml_ret, (char *) &ret);
done:
remoteDriverUnlock(priv);
- return interface;
+ return iface;
}
static int
-remoteInterfaceUndefine (virInterfacePtr interface)
+remoteInterfaceUndefine (virInterfacePtr iface)
{
int rv = -1;
remote_interface_undefine_args args;
- struct private_data *priv = interface->conn->interfacePrivateData;
+ struct private_data *priv = iface->conn->interfacePrivateData;
remoteDriverLock(priv);
- make_nonnull_interface (&args.interface, interface);
+ make_nonnull_interface (&args.iface, iface);
- if (call (interface->conn, priv, 0, REMOTE_PROC_INTERFACE_UNDEFINE,
+ if (call (iface->conn, priv, 0, REMOTE_PROC_INTERFACE_UNDEFINE,
(xdrproc_t) xdr_remote_interface_undefine_args, (char *) &args,
(xdrproc_t) xdr_void, (char *) NULL) == -1)
goto done;
@@ -4007,19 +4007,19 @@ done:
}
static int
-remoteInterfaceCreate (virInterfacePtr interface,
+remoteInterfaceCreate (virInterfacePtr iface,
unsigned int flags)
{
int rv = -1;
remote_interface_create_args args;
- struct private_data *priv = interface->conn->interfacePrivateData;
+ struct private_data *priv = iface->conn->interfacePrivateData;
remoteDriverLock(priv);
- make_nonnull_interface (&args.interface, interface);
+ make_nonnull_interface (&args.iface, iface);
args.flags = flags;
- if (call (interface->conn, priv, 0, REMOTE_PROC_INTERFACE_CREATE,
+ if (call (iface->conn, priv, 0, REMOTE_PROC_INTERFACE_CREATE,
(xdrproc_t) xdr_remote_interface_create_args, (char *) &args,
(xdrproc_t) xdr_void, (char *) NULL) == -1)
goto done;
@@ -4032,19 +4032,19 @@ done:
}
static int
-remoteInterfaceDestroy (virInterfacePtr interface,
+remoteInterfaceDestroy (virInterfacePtr iface,
unsigned int flags)
{
int rv = -1;
remote_interface_destroy_args args;
- struct private_data *priv = interface->conn->interfacePrivateData;
+ struct private_data *priv = iface->conn->interfacePrivateData;
remoteDriverLock(priv);
- make_nonnull_interface (&args.interface, interface);
+ make_nonnull_interface (&args.iface, iface);
args.flags = flags;
- if (call (interface->conn, priv, 0, REMOTE_PROC_INTERFACE_DESTROY,
+ if (call (iface->conn, priv, 0, REMOTE_PROC_INTERFACE_DESTROY,
(xdrproc_t) xdr_remote_interface_destroy_args, (char *) &args,
(xdrproc_t) xdr_void, (char *) NULL) == -1)
goto done;
@@ -7256,9 +7256,9 @@ get_nonnull_network (virConnectPtr conn,
}
static virInterfacePtr
-get_nonnull_interface (virConnectPtr conn, remote_nonnull_interface interface)
+get_nonnull_interface (virConnectPtr conn, remote_nonnull_interface iface)
{
- return virGetInterface (conn, interface.name, interface.mac);
+ return virGetInterface (conn, iface.name, iface.mac);
}
static virStoragePoolPtr
Index: tests/testutils.c
===================================================================
RCS file: /data/cvs/libvirt/tests/testutils.c,v
retrieving revision 1.28
diff -u -p -r1.28 testutils.c
--- tests/testutils.c 21 May 2009 14:22:51 -0000 1.28
+++ tests/testutils.c 28 May 2009 16:32:54 -0000
@@ -18,7 +18,9 @@
#ifndef WIN32
#include <sys/wait.h>
#endif
+#ifdef HAVE_REGEX_H
#include <regex.h>
+#endif
#include <unistd.h>
#include <string.h>
#include <fcntl.h>
@@ -460,6 +462,7 @@ cleanup:
}
+#ifdef HAVE_REGEX_H
int virtTestClearLineRegex(const char *pattern,
char *str)
{
@@ -503,3 +506,10 @@ int virtTestClearLineRegex(const char *p
return 0;
}
+#else
+int virtTestClearLineRegex(const char *pattern ATTRIBUTE_UNUSED,
+ char *str ATTRIBUTE_UNUSED)
+{
+ return 0;
+}
+#endif
Index: src/libvirt.c
===================================================================
RCS file: /data/cvs/libvirt/src/libvirt.c,v
retrieving revision 1.211
diff -u -p -r1.211 libvirt.c
--- src/libvirt.c 25 May 2009 11:56:00 -0000 1.211
+++ src/libvirt.c 28 May 2009 16:32:54 -0000
@@ -472,7 +472,7 @@ virLibNetworkError(virNetworkPtr network
* Handle an error at the connection level
*/
static void
-virLibInterfaceError(virInterfacePtr interface, virErrorNumber error,
+virLibInterfaceError(virInterfacePtr iface, virErrorNumber error,
const char *info)
{
virConnectPtr conn = NULL;
@@ -483,7 +483,7 @@ virLibInterfaceError(virInterfacePtr int
errmsg = virErrorMsg(error, info);
if (error != VIR_ERR_INVALID_INTERFACE) {
- conn = interface->conn;
+ conn = iface->conn;
}
virRaiseError(conn, NULL, NULL, VIR_FROM_INTERFACE, error, VIR_ERR_ERROR,
errmsg, info, NULL, 0, 0, errmsg, info);
@@ -5485,17 +5485,17 @@ error:
* Returns the virConnectPtr or NULL in case of failure.
*/
virConnectPtr
-virInterfaceGetConnect (virInterfacePtr interface)
+virInterfaceGetConnect (virInterfacePtr iface)
{
- DEBUG("interface=%p", interface);
+ DEBUG("iface=%p", iface);
virResetLastError();
- if (!VIR_IS_CONNECTED_INTERFACE (interface)) {
+ if (!VIR_IS_CONNECTED_INTERFACE (iface)) {
virLibInterfaceError (NULL, VIR_ERR_INVALID_INTERFACE, __FUNCTION__);
return NULL;
}
- return interface->conn;
+ return iface->conn;
}
/**
@@ -5663,7 +5663,7 @@ error:
/**
* virInterfaceGetName:
- * @interface: a interface object
+ * @iface: a interface object
*
* Get the public name for that interface
*
@@ -5671,22 +5671,22 @@ error:
* its lifetime will be the same as the interface object.
*/
const char *
-virInterfaceGetName(virInterfacePtr interface)
+virInterfaceGetName(virInterfacePtr iface)
{
- DEBUG("interface=%p", interface);
+ DEBUG("iface=%p", iface);
virResetLastError();
- if (!VIR_IS_INTERFACE(interface)) {
+ if (!VIR_IS_INTERFACE(iface)) {
virLibInterfaceError(NULL, VIR_ERR_INVALID_INTERFACE, __FUNCTION__);
return (NULL);
}
- return (interface->name);
+ return (iface->name);
}
/**
* virInterfaceGetMACString:
- * @interface: a interface object
+ * @iface: a interface object
*
* Get the MAC for a interface as string. For more information about
* MAC see RFC4122.
@@ -5696,22 +5696,22 @@ virInterfaceGetName(virInterfacePtr inte
* will be the same as the interface object.
*/
const char *
-virInterfaceGetMACString(virInterfacePtr interface)
+virInterfaceGetMACString(virInterfacePtr iface)
{
- DEBUG("interface=%p", interface);
+ DEBUG("iface=%p", iface);
virResetLastError();
- if (!VIR_IS_INTERFACE(interface)) {
+ if (!VIR_IS_INTERFACE(iface)) {
virLibInterfaceError(NULL, VIR_ERR_INVALID_INTERFACE, __FUNCTION__);
return (NULL);
}
- return (interface->mac);
+ return (iface->mac);
}
/**
* virInterfaceGetXMLDesc:
- * @interface: a interface object
+ * @iface: a interface object
* @flags: and OR'ed set of extraction flags, not used yet
*
* Provide an XML description of the interface. The description may be reused
@@ -5721,27 +5721,27 @@ virInterfaceGetMACString(virInterfacePtr
* the caller must free() the returned value.
*/
char *
-virInterfaceGetXMLDesc(virInterfacePtr interface, unsigned int flags)
+virInterfaceGetXMLDesc(virInterfacePtr iface, unsigned int flags)
{
virConnectPtr conn;
- DEBUG("interface=%p, flags=%d", interface, flags);
+ DEBUG("iface=%p, flags=%d", iface, flags);
virResetLastError();
- if (!VIR_IS_CONNECTED_INTERFACE(interface)) {
+ if (!VIR_IS_CONNECTED_INTERFACE(iface)) {
virLibInterfaceError(NULL, VIR_ERR_INVALID_INTERFACE, __FUNCTION__);
return (NULL);
}
if (flags != 0) {
- virLibInterfaceError(interface, VIR_ERR_INVALID_ARG, __FUNCTION__);
+ virLibInterfaceError(iface, VIR_ERR_INVALID_ARG, __FUNCTION__);
goto error;
}
- conn = interface->conn;
+ conn = iface->conn;
if (conn->interfaceDriver &&
conn->interfaceDriver->interfaceGetXMLDesc) {
char *ret;
- ret = conn->interfaceDriver->interfaceGetXMLDesc (interface, flags);
+ ret = conn->interfaceDriver->interfaceGetXMLDesc (iface, flags);
if (!ret)
goto error;
return ret;
@@ -5751,7 +5751,7 @@ virInterfaceGetXMLDesc(virInterfacePtr i
error:
/* Copy to connection error object for back compatability */
- virSetConnError(interface->conn);
+ virSetConnError(iface->conn);
return NULL;
}
@@ -5803,7 +5803,7 @@ error:
/**
* virInterfaceUndefine:
* @interface: pointer to a defined interface
*
* Undefine an interface, ie remove it from the config.
* This does not free the associated virInterfacePtr object.
@@ -5811,25 +5811,25 @@ error:
* Returns 0 in case of success, -1 in case of error
*/
int
-virInterfaceUndefine(virInterfacePtr interface) {
+virInterfaceUndefine(virInterfacePtr iface) {
virConnectPtr conn;
- DEBUG("interface=%p", interface);
+ DEBUG("iface=%p", iface);
virResetLastError();
- if (!VIR_IS_CONNECTED_INTERFACE(interface)) {
+ if (!VIR_IS_CONNECTED_INTERFACE(iface)) {
virLibInterfaceError(NULL, VIR_ERR_INVALID_INTERFACE, __FUNCTION__);
return (-1);
}
- conn = interface->conn;
+ conn = iface->conn;
if (conn->flags & VIR_CONNECT_RO) {
- virLibInterfaceError(interface, VIR_ERR_OPERATION_DENIED, __FUNCTION__);
+ virLibInterfaceError(iface, VIR_ERR_OPERATION_DENIED, __FUNCTION__);
goto error;
}
if (conn->interfaceDriver &&
conn->interfaceDriver->interfaceUndefine) {
int ret;
- ret = conn->interfaceDriver->interfaceUndefine (interface);
+ ret = conn->interfaceDriver->interfaceUndefine (iface);
if (ret < 0)
goto error;
return ret;
@@ -5839,13 +5839,13 @@ virInterfaceUndefine(virInterfacePtr int
error:
/* Copy to connection error object for back compatability */
- virSetConnError(interface->conn);
+ virSetConnError(iface->conn);
return -1;
}
/**
* virInterfaceCreate:
* @interface: pointer to a defined interface
* @flags: and OR'ed set of extraction flags, not used yet
*
* Activate an interface (ie call "ifup")
@@ -5853,26 +5853,26 @@ error:
* Returns 0 in case of success, -1 in case of error
*/
int
-virInterfaceCreate(virInterfacePtr interface, unsigned int flags)
+virInterfaceCreate(virInterfacePtr iface, unsigned int flags)
{
virConnectPtr conn;
- DEBUG("interface=%p, flags=%d", interface, flags);
+ DEBUG("iface=%p, flags=%d", iface, flags);
virResetLastError();
- if (!VIR_IS_CONNECTED_INTERFACE(interface)) {
+ if (!VIR_IS_CONNECTED_INTERFACE(iface)) {
virLibInterfaceError(NULL, VIR_ERR_INVALID_INTERFACE, __FUNCTION__);
return (-1);
}
- conn = interface->conn;
+ conn = iface->conn;
if (conn->flags & VIR_CONNECT_RO) {
- virLibInterfaceError(interface, VIR_ERR_OPERATION_DENIED, __FUNCTION__);
+ virLibInterfaceError(iface, VIR_ERR_OPERATION_DENIED, __FUNCTION__);
goto error;
}
if (conn->interfaceDriver && conn->interfaceDriver->interfaceCreate)
{
int ret;
- ret = conn->interfaceDriver->interfaceCreate (interface, flags);
+ ret = conn->interfaceDriver->interfaceCreate (iface, flags);
if (ret < 0)
goto error;
return ret;
@@ -5882,13 +5882,13 @@ virInterfaceCreate(virInterfacePtr inter
error:
/* Copy to connection error object for back compatability */
- virSetConnError(interface->conn);
+ virSetConnError(iface->conn);
return -1;
}
/**
* virInterfaceDestroy:
* @interface: an interface object
* @flags: and OR'ed set of extraction flags, not used yet
*
* deactivate an interface (ie call "ifdown")
@@ -5898,27 +5898,27 @@ error:
* Returns 0 in case of success and -1 in case of failure.
*/
int
-virInterfaceDestroy(virInterfacePtr interface, unsigned int flags)
+virInterfaceDestroy(virInterfacePtr iface, unsigned int flags)
{
virConnectPtr conn;
- DEBUG("interface=%p, flags=%d", interface, flags);
+ DEBUG("iface=%p, flags=%d", iface, flags);
virResetLastError();
- if (!VIR_IS_CONNECTED_INTERFACE(interface)) {
+ if (!VIR_IS_CONNECTED_INTERFACE(iface)) {
virLibInterfaceError(NULL, VIR_ERR_INVALID_INTERFACE, __FUNCTION__);
return (-1);
}
- conn = interface->conn;
+ conn = iface->conn;
if (conn->flags & VIR_CONNECT_RO) {
- virLibInterfaceError(interface, VIR_ERR_OPERATION_DENIED, __FUNCTION__);
+ virLibInterfaceError(iface, VIR_ERR_OPERATION_DENIED, __FUNCTION__);
goto error;
}
if (conn->interfaceDriver &&
conn->interfaceDriver->interfaceDestroy) {
int ret;
- ret = conn->interfaceDriver->interfaceDestroy (interface, flags);
+ ret = conn->interfaceDriver->interfaceDestroy (iface, flags);
if (ret < 0)
goto error;
return ret;
@@ -5928,13 +5928,13 @@ virInterfaceDestroy(virInterfacePtr inte
error:
/* Copy to connection error object for back compatability */
- virSetConnError(interface->conn);
+ virSetConnError(iface->conn);
return -1;
}
/**
* virInterfaceRef:
* @interface: the interface to hold a reference on
*
* Increment the reference count on the interface. For each
* additional call to this method, there shall be a corresponding
@@ -5950,22 +5950,22 @@ error:
* Returns 0 in case of success, -1 in case of failure.
*/
int
-virInterfaceRef(virInterfacePtr interface)
+virInterfaceRef(virInterfacePtr iface)
{
- if ((!VIR_IS_CONNECTED_INTERFACE(interface))) {
+ if ((!VIR_IS_CONNECTED_INTERFACE(iface))) {
virLibConnError(NULL, VIR_ERR_INVALID_ARG, __FUNCTION__);
return(-1);
}
- virMutexLock(&interface->conn->lock);
- DEBUG("interface=%p refs=%d", interface, interface->refs);
- interface->refs++;
- virMutexUnlock(&interface->conn->lock);
+ virMutexLock(&iface->conn->lock);
+ DEBUG("iface=%p refs=%d", iface, iface->refs);
+ iface->refs++;
+ virMutexUnlock(&iface->conn->lock);
return 0;
}
/**
* virInterfaceFree:
- * @interface: a interface object
+ * @iface: a interface object
*
* Free the interface object. The interface itself is unaltered.
* The data structure is freed and should not be used thereafter.
@@ -5973,17 +5973,17 @@ virInterfaceRef(virInterfacePtr interfac
* Returns 0 in case of success and -1 in case of failure.
*/
int
-virInterfaceFree(virInterfacePtr interface)
+virInterfaceFree(virInterfacePtr iface)
{
- DEBUG("interface=%p", interface);
+ DEBUG("iface=%p", iface);
virResetLastError();
- if (!VIR_IS_CONNECTED_INTERFACE(interface)) {
+ if (!VIR_IS_CONNECTED_INTERFACE(iface)) {
virLibInterfaceError(NULL, VIR_ERR_INVALID_INTERFACE, __FUNCTION__);
return (-1);
}
- if (virUnrefInterface(interface) < 0)
+ if (virUnrefInterface(iface) < 0)
return (-1);
return(0);
}
@@ -5803,7 +5803,7 @@ error:
/**
* virInterfaceUndefine:
- * @interface: pointer to a defined interface
+ * @iface: pointer to a defined interface
*
* Undefine an interface, ie remove it from the config.
@@ -5839,13 +5839,13 @@ virInterfaceUndefine(virInterfacePtr int
/**
* virInterfaceCreate:
- * @interface: pointer to a defined interface
+ * @iface: pointer to a defined interface
* @flags: and OR'ed set of extraction flags, not used yet
*
@@ -5882,13 +5882,13 @@ virInterfaceCreate(virInterfacePtr inter
/**
* virInterfaceDestroy:
- * @interface: an interface object
+ * @iface: an interface object
* @flags: and OR'ed set of extraction flags, not used yet
*
@@ -5928,13 +5928,13 @@ virInterfaceDestroy(virInterfacePtr inte
/**
* virInterfaceRef:
- * @interface: the interface to hold a reference on
+ * @iface: the interface to hold a reference on
*
* Increment the reference count on the interface. For each
--
|: Red Hat, Engineering, London -o-
http://people.redhat.com/berrange/ :|
|:
http://libvirt.org -o-
http://virt-manager.org -o-
http://ovirt.org :|
|:
http://autobuild.org -o-
http://search.cpan.org/~danberr/ :|
|: GnuPG: 7D3B9505 -o- F3C9 553F A1DA 4AC2 5648 23C1 B3DF F742 7D3B 9505 :|